@@ -1,7 +1,9 @@
+use std::time::Instant;
+
 #[derive(Clone)]
 pub struct Paste {
-    /// Paste lifetime (in minutes)
-    pub lifetime: u32,
+    /// Paste lifetime
+    pub lifetime: Instant,
     /// HTTP conntent type
     pub content_type: String,
     /// Paste content
@@ -9,17 +11,17 @@ pub struct Paste {
 }
 
 impl Paste {
-    pub fn new_plain(lifetime: u32, content: Vec<u8>) -> Self {
+    pub fn new_plain(content: Vec<u8>) -> Self {
         Self {
-            lifetime,
+            lifetime: Instant::now(),
             content,
             content_type: "text/plain; charset=utf-8".to_string(),
         }
     }
 
-    pub fn new_html(lifetime: u32, content: Vec<u8>) -> Self {
+    pub fn new_html(content: Vec<u8>) -> Self {
         Self {
-            lifetime,
+            lifetime: Instant::now(),
             content,
             content_type: "text/html; charset=utf-8".to_string(),
         }
